==> certmanager-model-v1alpha3-6.7.2-sources.jar: io/fabric8/certmanager/api/model/v1alpha3/X509SubjectBuilder.java <==
package io.fabric8.certmanager.api.model.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class X509SubjectBuilder extends X509SubjectFluentImpl<X509SubjectBuilder> implements VisitableBuilder<X509Subject,X509SubjectBuilder>{
  public X509SubjectBuilder() {
    this(false);
  }
  public X509SubjectBuilder(Boolean validationEnabled) {
    this(new X509Subject(), validationEnabled);
  }
  public X509SubjectBuilder(X509SubjectFluent<?> fluent) {
    this(fluent, false);
  }
  public X509SubjectBuilder(X509SubjectFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new X509Subject(), validationEnabled);
  }
  public X509SubjectBuilder(X509SubjectFluent<?> fluent,X509Subject instance) {
    this(fluent, instance, false);
  }
  public X509SubjectBuilder(X509SubjectFluent<?> fluent,X509Subject instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withCountries(instance.getCountries());
      fluent.withLocalities(instance.getLocalities());
      fluent.withOrganizationalUnits(instance.getOrganizationalUnits());
      fluent.withOrganizations(instance.getOrganizations());
      fluent.withPostalCodes(instance.getPostalCodes());
      fluent.withProvinces(instance.getProvinces());
      fluent.withSerialNumber(instance.getSerialNumber());
      fluent.withStreetAddresses(instance.getStreetAddresses());
    }
    this.validationEnabled = validationEnabled; 
  }
  public X509SubjectBuilder(X509Subject instance) {
    this(instance,false);
  }
  public X509SubjectBuilder(X509Subject instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withCountries(instance.getCountries());
      this.withLocalities(instance.getLocalities());
      this.withOrganizationalUnits(instance.getOrganizationalUnits());
      this.withOrganizations(instance.getOrganizations());
      this.withPostalCodes(instance.getPostalCodes());
      this.withProvinces(instance.getProvinces());
      this.withSerialNumber(instance.getSerialNumber());
      this.withStreetAddresses(instance.getStreetAddresses());
    }
    this.validationEnabled = validationEnabled; 
  }
  X509SubjectFluent<?> fluent;
  Boolean validationEnabled;
  public X509Subject build() {
    X509Subject buildable = new X509Subject(fluent.getCountries(),fluent.getLocalities(),fluent.getOrganizationalUnits(),fluent.getOrganizations(),fluent.getPostalCodes(),fluent.getProvinces(),fluent.getSerialNumber(),fluent.getStreetAddresses());
    return buildable;
  }
  
}

==> certmanager-model-v1alpha3-6.8.0-sources.jar: io/fabric8/certmanager/api/model/v1alpha3/X509SubjectBuilder.java <==
package io.fabric8.certmanager.api.model.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class X509SubjectBuilder extends X509SubjectFluent<X509SubjectBuilder> implements VisitableBuilder<X509Subject,X509SubjectBuilder>{
  public X509SubjectBuilder() {
    this(false);
  }
  public X509SubjectBuilder(Boolean validationEnabled) {
    this(new X509Subject(), validationEnabled);
  }
  public X509SubjectBuilder(X509SubjectFluent<?> fluent) {
    this(fluent, false);
  }
  public X509SubjectBuilder(X509SubjectFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new X509Subject(), validationEnabled);
  }
  public X509SubjectBuilder(X509SubjectFluent<?> fluent,X509Subject instance) {
    this(fluent, instance, false);
  }
  public X509SubjectBuilder(X509SubjectFluent<?> fluent,X509Subject instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new X509Subject());

    if (instance != null) {
      fluent.withCountries(instance.getCountries());
      fluent.withLocalities(instance.getLocalities());
      fluent.withOrganizationalUnits(instance.getOrganizationalUnits());
      fluent.withOrganizations(instance.getOrganizations());
      fluent.withPostalCodes(instance.getPostalCodes());
      fluent.withProvinces(instance.getProvinces());
      fluent.withSerialNumber(instance.getSerialNumber());
      fluent.withStreetAddresses(instance.getStreetAddresses());
      fluent.withCountries(instance.getCountries());
      fluent.withLocalities(instance.getLocalities());
      fluent.withOrganizationalUnits(instance.getOrganizationalUnits());
      fluent.withOrganizations(instance.getOrganizations());
      fluent.withPostalCodes(instance.getPostalCodes());
      fluent.withProvinces(instance.getProvinces());
      fluent.withSerialNumber(instance.getSerialNumber());
      fluent.withStreetAddresses(instance.getStreetAddresses());
    }
    this.validationEnabled = validationEnabled; 
  }
  public X509SubjectBuilder(X509Subject instance) {
    this(instance,false);
  }
  public X509SubjectBuilder(X509Subject instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new X509Subject());

    if (instance != null) {
      this.withCountries(instance.getCountries());
      this.withLocalities(instance.getLocalities());
      this.withOrganizationalUnits(instance.getOrganizationalUnits());
      this.withOrganizations(instance.getOrganizations());
      this.withPostalCodes(instance.getPostalCodes());
      this.withProvinces(instance.getProvinces());
      this.withSerialNumber(instance.getSerialNumber());
      this.withStreetAddresses(instance.getStreetAddresses());
      this.withCountries(instance.getCountries());
      this.withLocalities(instance.getLocalities());
      this.withOrganizationalUnits(instance.getOrganizationalUnits());
      this.withOrganizations(instance.getOrganizations());
      this.withPostalCodes(instance.getPostalCodes());
      this.withProvinces(instance.getProvinces());
      this.withSerialNumber(instance.getSerialNumber());
      this.withStreetAddresses(instance.getStreetAddresses());
    }
    this.validationEnabled = validationEnabled; 
  }
  X509SubjectFluent<?> fluent;
  Boolean validationEnabled;
  public X509Subject build() {
    X509Subject buildable = new X509Subject(fluent.getCountries(),fluent.getLocalities(),fluent.getOrganizationalUnits(),fluent.getOrganizations(),fluent.getPostalCodes(),fluent.getProvinces(),fluent.getSerialNumber(),fluent.getStreetAddresses());
    return buildable;
  }
  
}
